import { EventEmitter, once } from 'stream';
import { load, CodeManager, CodeStatus, loadOne } from './load.ts';
import { RouterCodeModel } from '../../models/code.ts';

export enum LoadStatus {
  LOADING = 'loading',
  LOADED = 'loaded',
  ERROR = 'error',
}
export const manager = {
  loaded: LoadStatus.LOADING, // 是否已经加载
  list: [] as CodeManager[],
  shareLocalList: [] as CodeManager[],
};

// 更新
export const updateNewCode = (code: CodeManager) => {
  const index = manager.list.findIndex((item) => item.id === code.id);
  if (index === -1) {
    manager.list.push(code);
  } else {
    manager.list[index] = code;
  }
};
// 删除
export const removeCode = (id: string) => {
  const index = manager.list.findIndex((item) => item.id === id);
  if (index !== -1) {
    manager.list.splice(index, 1);
  }
};
export const stopCode = (id: string) => {
  const index = manager.list.findIndex((item) => item.id === id);
  if (index !== -1) {
    manager.list[index].status = CodeStatus.stop;
  }
};
export const startCode = async (code: RouterCodeModel) => {
  const index = manager.list.findIndex((item) => item.id === code.id);
  console.log('index', index, code.toJSON())
  if (index !== -1) {
    manager.list[index] = await loadOne(code);
  } else {
    const codeManger = await loadOne(code);
    manager.list.push(codeManger);
  }
};

// 事件
export const events = new EventEmitter();

once(events, 'loaded')
  .then(() => {
    manager.loaded = LoadStatus.LOADED;
    console.log('manager loaded');
  })
  .catch((e) => {
    manager.loaded = LoadStatus.ERROR;
    console.error('manager loaded error', e);
  });

const init = async function () {
  const r = await load();
  manager.list = r;

  events.emit('loaded');
};

init();
