import { exec } from 'child_process';
import path from 'path';
import fs from 'fs';

export const directoryPath = path.resolve(__dirname);
const packagePath = path.resolve(directoryPath, 'package.json');
const exists = (filePath: string) => {
  try {
    fs.accessSync(filePath);
    return true;
  } catch (e) {
    return false;
  }
};

export const installPackage = async (packageName: string) => {
  if (!exists(packagePath)) {
    fs.writeFileSync(packagePath, JSON.stringify({ name: 'npm-install', version: '1.0.0' }), 'utf-8');
  }
  return await new Promise((resolve, reject) => {
    console.log(`Starting installation of ${packageName}...`);
    // 在程序运行路径下执行 npm install 命令
    console.log(`npm install ${packageName}`);

    exec(`npm install ${packageName}`, { cwd: directoryPath }, (error, stdout, stderr) => {
      if (error) {
        console.error(`Error installing package: ${stderr}`);
        reject(new Error(`Failed to install package ${packageName}`));
      } else {
        console.log(`Package ${packageName} installed successfully: ${stdout}`);
        resolve(stdout);
      }
    });
  });
};
export const getPackage = async () => {
  if (!exists(packagePath)) {
    return {};
  }
  try {
    return JSON.parse(fs.readFileSync(packagePath, 'utf-8'));
  } catch (e) {
    console.error('Failed to read package.json');
    return {};
  }
};
