import { sequelize } from '../modules/sequelize.ts';
import { DataTypes, Model } from 'sequelize';
import { Variable } from '@kevisual/ai-graph';

export type ChatPromptData = {
  // 使用那个agent, 必须要有
  aiAgentId: string;
  // 使用那个初始化的prompt，如果不存在则纯粹的白对话。
  promptId?: string;
};
/**
 * chat绑定就的agent和prompt
 * 有一些内容是预置的。
 */
export class ChatPrompt extends Model {
  declare id: string;
  declare title: string;
  declare description: string;
  declare uid: string;
  declare key: string;
  declare data: string;
}

ChatPrompt.init(
  {
    id: {
      type: DataTypes.UUID,
      primaryKey: true,
      defaultValue: DataTypes.UUIDV4,
    },
    title: {
      type: DataTypes.STRING,
      allowNull: false,
    },
    description: {
      type: DataTypes.TEXT,
      allowNull: true,
    },
    data: {
      type: DataTypes.JSON,
      allowNull: true,
    },
    key: {
      type: DataTypes.STRING, // 页面属于 /container/edit/list
      allowNull: false,
    },
    uid: {
      type: DataTypes.STRING,
      allowNull: true,
    },
  },
  {
    sequelize, // 传入 Sequelize 实例
    modelName: 'chat_prompt', // 模型名称
  },
);

// force 只能run一次，否则会删除表
ChatPrompt.sync({ alter: true, force: true, logging: false }).catch((e) => {
  console.error('Prompt sync error', e);
});
