import { CustomError } from '@abearxiong/router';
import { app } from '../../app.ts';
import { ContainerModel, ContainerData, Container } from './models/index.ts';
import semver from 'semver';
const list = app.route({
  path: 'container',
  key: 'list',
  middleware: ['auth']
});

list.run = async (ctx) => {
  const tokenUser = ctx.state.tokenUser;
  const list = await ContainerModel.findAll({
    order: [['updatedAt', 'DESC']],
    where: {
      uid: tokenUser.id,
    },
  });
  ctx.body = list;
  return ctx;
};

list.addTo(app);

app
  .route({
    path: 'container',
    key: 'get',
  })
  .define(async (ctx) => {
    const id = ctx.query.id;
    if (!id) {
      throw new CustomError('id is required');
    }
    ctx.body = await ContainerModel.findByPk(id);
    return ctx;
  })
  .addTo(app);

const add = app.route({
  path: 'container',
  key: 'update',
});
add.run = async (ctx) => {
  const data = ctx.query.data;

  const _data: Container = {
    title: '',
    description: '',
    code: '',
    type: '',
  };
  const container = {
    ..._data,
    ...data,
  };
  let containerModel: any = null;
  if (container.id) {
    containerModel = await ContainerModel.findByPk(container.id);
    if (containerModel) {
      containerModel.update(container);
      await containerModel.save();
      ctx.emit?.('pageEdit', {
        source: 'container',
        data: containerModel.toJSON(),
        operation: 'edit',
      });
    }
  } else {
    try {
      containerModel = await ContainerModel.create({
        ...container,
        source: '',
        sourceType: '',
      });
    } catch (e) {
      console.log('error', e);
    }
    console.log('containerModel', container);
  }

  ctx.body = containerModel;
  return ctx;
};
add.addTo(app);

const deleteRoute = app.route({
  path: 'container',
  key: 'delete',
});
deleteRoute.run = async (ctx) => {
  const id = ctx.query.id;
  const container = await ContainerModel.findByPk(id);
  if (container) {
    await container.destroy();
  }
  ctx.body = container;
  return ctx;
};
deleteRoute.addTo(app);

app
  .route({
    path: 'container',
    key: 'publish',
    nextRoute: { path: 'resource', key: 'publishContainer' },
  })
  .define(async (ctx) => {
    const { data } = ctx.query;
    const { id, publish, type = 'patch', beta = false } = data;
    type PublishType = 'patch' | 'minor' | 'major';
    if (!id) {
      throw new CustomError('id is required');
    }
    const container = await ContainerModel.findByPk(id);
    if (!container) {
      throw new CustomError('container not found');
    }
    const { name, description } = publish;
    const oldPublish = container.publish;
    let _version = '';
    if (!oldPublish.version) {
      if (publish.name) {
        throw new CustomError('publish name is required');
      }
      container.publish = {
        name,
        description,
        version: '0.0.1',
      };
    } else {
      _version = semver.inc(oldPublish.version, type as PublishType, beta ? 'beta' : undefined);
      container.publish.version = _version;
    }
    if (ctx.state) {
      ctx.state.container = container;
    } else {
      ctx.state = {
        container,
      };
    }
    // 执行下一步操作了
    ctx.body = 'run ok';
  })
  .addTo(app);
