import { PromptNeo, createRelationship, createRelationship2 } from '@/models/prompt-graph.ts';
import { app } from '@/app.ts';
import { v4 } from 'uuid';
import { fetchData } from './d3/get-graph.ts';
app
  .route('prompt-graph', 'list')
  .define(async (ctx) => {
    const prompts = await PromptNeo.all();
    const json = await prompts.toJson();
    // console.log('json', json);
    ctx.body = json;
  })
  .addTo(app);

app
  .route('prompt-graph', 'update')
  .define(async (ctx) => {
    const { id, title, description, prompt, inputVariables, localVariables } = ctx.query;
    const promptNode = await PromptNeo.first('id', id);

    if (!promptNode) {
      const promptData = {
        id: v4(),
        title,
        description,
        prompt,
        inputVariables: JSON.stringify(inputVariables),
        localVariables: JSON.stringify(localVariables),
      };
      const _prompt = await PromptNeo.create(promptData);
      ctx.body = await _prompt.toJson();
      return;
    }

    await promptNode.update({ title, description, prompt, inputVariables, localVariables });
    ctx.body = await promptNode.toJson();
  })
  .addTo(app);

app
  .route('prompt-graph', 'delete')
  .define(async (ctx) => {
    const { id, title } = ctx.query;
    const promptNode = await PromptNeo.first('id', id);
    if (!promptNode) {
      ctx.body = 'prompt not found';
      return;
    }
    await promptNode.delete();
    ctx.body = 'delete success';
  })
  .addTo(app);
app
  .route('prompt-graph', 'deleteAll')
  .define(async (ctx) => {
    const prompts = await PromptNeo.all();
    for (const prompt of prompts) {
      await prompt.delete();
    }
    ctx.body = 'delete all success';
  })
  .addTo(app);
app
  .route('prompt-graph', 'createDemo')
  .define(async (ctx) => {
    const promptData = {
      id: v4(),
      title: 'test-' + v4(),
      description: '这是测试保存prompt的数据',
      prompt: '这是测试保存prompt的数据',
      inputVariables: JSON.stringify([{ key: 'test', value: 'test' }]),
      localVariables: JSON.stringify([{ key: 'test', value: 'test' }]),
    };
    const f = await PromptNeo.first('id', 'f5288cdb-bfca-4a65-b629-cae590ede719');
    if (!f) {
      ctx.body = 'not found f';
      return;
    }
    const prompt = await PromptNeo.create({ ...promptData });
    // await prompt.relateTo(f, 'RELATED_TO', { createdAt: new Date().toISOString() });
    // f.relateTo(prompt, 'RELATED_TO', { createdAt: new Date().toISOString() });
    // await createRelationship(f, prompt);
    const fj = await f.toJson() as any;
    const pj = await prompt.toJson() as any;

    await createRelationship2(fj.id, pj.id);
    ctx.body = await prompt.toJson();
  })
  .addTo(app);

app
  .route('prompt-graph', 'getD3')
  .define(async (ctx) => {
    const value = await fetchData();
    ctx.body = value;
  })
  .addTo(app);
