import { Prompt } from '@/models/prompt.ts';

import { app } from '@/app.ts';
import { CustomError } from '@abearxiong/router';

app
  .route('prompt', 'list')
  .define(async (ctx) => {
    const prompts = await Prompt.findAll({
      order: [['updatedAt', 'DESC']],
    });
    ctx.body = prompts;
  })
  .addTo(app);

app
  .route('prompt', 'update')
  .define(async (ctx) => {
    const { id, title, description, presetData, key } = ctx.query.data || {};
    if (!key) {
      throw new CustomError('Prompt key is required');
    }
    const isEdit = !!id;
    const promptKey = await Prompt.findOne({ where: { key } });
    if (promptKey && promptKey.id !== id) {
      throw new CustomError(`Prompt key is already exist, use by ${promptKey.id}`);
    }
    if (!isEdit) {
      const prompt = new Prompt({
        title,
        key,
        description,
        presetData,
      });
      await prompt.save();
      ctx.body = prompt;
      return;
    }

    const prompt = await Prompt.findByPk(id);
    if (!prompt) {
      throw new CustomError('Prompt not found');
    }
    await prompt.update({ title, description, presetData, key });
    ctx.body = prompt;
  })
  .addTo(app);

app
  .route('prompt', 'delete')
  .define(async (ctx) => {
    const { id } = ctx.query || {};
    if (!id) {
      throw new CustomError('Prompt id is required');
    }
    const prompt = await Prompt.findByPk(id);
    if (!prompt) {
      throw new CustomError('Prompt not found');
    }
    await prompt.destroy();
    ctx.body = 'delete success';
  })
  .addTo(app);
